/*
** Module   : ServerPropertiesDaemon.java
** Abstract : Server side daemon to handle Progress 4GL compatible OS properties handling.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20140325 Created initial version to inspect some system properties on the server side.
*/

package com.goldencode.p2j.util;

import java.io.*;

/**
 * A client side class to manipulate with environments. The environment can be the INI file or
 * registry sections containing the keys.
 *
 * @author    EVL
 */
public class ServerPropertiesDaemon
{
   /**
    * Gets the current version string of the Progress compatible environment.
    * <p>
    * If no value is found via this lookup, then the default value of
    * "10.2B" will be returned.
    *
    * @return   The current version string.
    */
   public static String getVersion()
   {
      return EnvironmentOps.getVersion().toStringMessage();
   }

   /**
    * Reports if the current server context is running in batch mode.
    * <p>
    * If no value is found via this lookup, then the default value of
    * <code>false</code> will be returned.
    *
    * @return   <code>true</code> if the current context is in batch mode.
    */
   public static boolean isBatchMode()
   {
      return EnvironmentOps.isBatchMode().booleanValue();
   }
}
